TOKEN_START_OF_TRACE = 'SOT'
TOKEN_END_OF_TRACE = 'EOT'
TOKEN_DEFAULT = 'Other'

TOKEN_END_OF_STREAM = None
